import os
import sys

sys.path.insert(0, os.path.dirname(os.path.abspath('.')))

project = 'test'
